##  Best Practices
  * Promote collaboration: Avoid measures that restrict the majority of users from contributing to data quality in the workspace. Instead, foster an environment that encourages active participation for improved data quality and accuracy.
  * Restrict access to sensitive data: Prioritize limiting access to business-critical or sensitive data. By doing this, you ensure that crucial data remains secure, while allowing for wider collaboration on less sensitive information.
  * Test permissions: To ensure that fact sheet permissions are set up correctly for a specific user role, you can temporarily preview the workspace under this role. To do that, in the user profile menu, select Switch user role, select a role, then click Login.
